#!/bin/bash

# Local Variables: ***
# mode: Shell-script ***
# coding: utf-8 ***
# End: ***

# createtexfile_kanji.sh
# Create LaTeX-file that shows certain Japanese char in many fonts
# Compile it and move to right directory.
# Just like createtexfile.sh but this is for kanjis:
# It has all kind of information about each kanji, like on-yomi and kun-yomi.

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This script is public domain. There is no warranty.

# Usage:
# createtexfile.sh (character) GROUP SUBGROUP
# Example: 
# createtexfile.sh あ hiragana basic


CHARMAP="`locale charmap`"

if test "$CHARMAP" == "UTF-8"
then
    echo "Your environment is UTF-8-safe"
else
    echo "Your environment is not UTF-8-safe"
    exit 1
fi

if test \("$1" = ""\) -o \("$2" = ""\) -o \("$3" = ""\) -o \( "$#" -lt 3 \)
then
    echo "Usage:"
    echo "$0 (character) (group) (subgroup)"
    echo "Example: $0 あ hiragana basic"
    exit 1
fi

CURRCHAR="${1}"

echo CURRCHAR=${CURRCHAR}

CURRUCS="`unicode --colour=off ${1} | head -n 1`"

echo CURRUCS=${CURRUCS}

CURRVAL="`unicode --colour=off ${1} | head -n 1 | awk '{print $1}'`"

echo CURRVAL=${CURRVAL}

FILENAME="${CURRVAL}.tex"

# Starting LaTeX-file (do not strip comments)
cp -f fontsamples_top_kanji.tex ${FILENAME}
# More starting LaTeX-file (strip comments)
cat fontsamples_start_kanji_A.tex | egrep -v '^%' >> ${FILENAME}

# Stroke order and information about that kanji
# (Needs environment-variables very much)

echo '\begin{minipage}[b]{0.40\textwidth}' >> ${FILENAME}
echo '\fontsize{\mystrokesize}{\mystrokespace}\selectfont' >> ${FILENAME}
echo '\setlength{\parindent}{0mm}' >> ${FILENAME}
echo '\fontspec{KanjiStrokeOrders}\mycurrentchar' >> ${FILENAME}

#echo '\begin{minipage}[b]{0.02\textwidth}' >> ${FILENAME}
#echo '\setlength{\parindent}{0mm}' >> ${FILENAME}
#echo '%b\\' >> ${FILENAME}
#echo '\end{minipage}%' >> ${FILENAME}

echo '\end{minipage}%' >> ${FILENAME}
echo '\begin{minipage}[b]{0.60\textwidth}' >> ${FILENAME}
echo '\begin{sloppypar}' >> ${FILENAME}
echo '\setlength{\parindent}{0mm}' >> ${FILENAME}
echo '\begin{flushleft}' >> ${FILENAME}
echo '\raggedright' >> ${FILENAME}

rm -f ${CURRVAL}.unihan 2> /dev/null
grep "${CURRVAL}	" Unihan.txt > ${CURRVAL}.unihan

rm -f ${CURRVAL}.xml2 2> /dev/null
xml2 < kanjidic2.xml | sed "1,/\/kanjidic2\/character\/literal=${CURRCHAR}/d" | sed '/^\/kanjidic2\/character\/literal=.*$/,$d' | grep -v '/kanjidic2/!= Entry for Kanji:' > ${CURRVAL}.xml2

MEANING="`grep '/kanjidic2/character/reading_meaning/rmgroup/meaning' < ${CURRVAL}.xml2 | sed '/^\/kanjidic2\/character\/reading_meaning\/rmgroup\/meaning\/@.*$/,$d' | egrep -v '^/kanjidic2/character/reading_meaning/rmgroup/meaning$' | sed 's/\/kanjidic2\/character\/reading_meaning\/rmgroup\/meaning=//' | sed 's/$/\;/' | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./' | sed 's/\&/\\\&/g' | sed 's/\_/\\\_/g'`"

if test "$MEANING" = "" -o  "$MEANING" = " "
then
    #MEANING="`grep kDefinition ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./' | sed 's/\&/\\\&/g' | sed 's/\_/\\\_/g'`"
    MEANING="`grep kDefinition ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\&/\\\&/g' | sed 's/\_/\\\_/g'`"
    if test "$MEANING" = "" -o  "$MEANING" = " "
    then
        echo "MEANING=${MEANING}"
        printf '%b\\textbf{Meaning (Unihan):} ' >> ${FILENAME}
        printf '%b\\textsf{' >> ${FILENAME}
        printf "${MEANING} " >> ${FILENAME}
        printf '}' >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    else
        echo "MEANING=${MEANING}"
        printf '%b\\textbf{Meaning (Unihan):} ' >> ${FILENAME}
        printf '%b\\textsf{' >> ${FILENAME}
        printf "${MEANING} " >> ${FILENAME}
        printf '}' >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    fi
else
    echo "MEANING=${MEANING}"
    printf '%b\\textbf{Meaning:} ' >> ${FILENAME}
    printf "${MEANING} " >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

ONYOMI="`egrep -A 1 '^/kanjidic2/character/reading_meaning/rmgroup/reading/@r_type=ja_on$' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/reading_meaning/rmgroup/reading/@r_type=ja_on$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/reading_meaning\/rmgroup\/reading=//' | sed 's/$/\;/' | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./'`"

if test "$ONYOMI" = "" -o  "$ONYOMI" = " "
then
    ONYOMI="`grep kJapaneseOn ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./' | sed 's/\&/\\\&/g' | sed 's/\_/\\\_/g'`"
    if test "$ONYOMI" = "" -o  "$ONYOMI" = " "
    then
        echo "ONYOMI=${ONYOMI}"
        printf '%b\\textbf{On-Yomi:} ' >> ${FILENAME}
        printf '%b\\textsf{' >> ${FILENAME}
        printf "${ONYOMI}" >> ${FILENAME}
        printf '}' >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    else
        echo "ONYOMI=${ONYOMI}"
        printf '%b\\textbf{On-Yomi (Unihan):} ' >> ${FILENAME}
        printf '%b\\textsf{' >> ${FILENAME}
        printf "${ONYOMI}" >> ${FILENAME}
        printf '}' >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    fi
else
    echo "ONYOMI=${ONYOMI}"
    printf '%b\\textbf{On-Yomi:} ' >> ${FILENAME}
    printf '%b\\textsf{' >> ${FILENAME}
    printf "${ONYOMI}" >> ${FILENAME}
    printf '}' >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi


KUNYOMI="`egrep -A 1 '^/kanjidic2/character/reading_meaning/rmgroup/reading/@r_type=ja_kun$' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/reading_meaning/rmgroup/reading/@r_type=ja_kun$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/reading_meaning\/rmgroup\/reading=//' | sed 's/$/\;/' | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./'`"

if test "$KUNYOMI" = "" -o  "$KUNYOMI" = " "
then
    KUNYOMI="`grep kJapaneseKun ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./' | sed 's/\&/\\\&/g' | sed 's/\_/\\\_/g'`"
    if test "$KUNYOMI" = "" -o  "$KUNYOMI" = " "
    then
        echo "KUNYOMI=${KUNYOMI}"
        printf '%b\\textbf{Kun-Yomi:} ' >> ${FILENAME}
        printf '%b\\textsf{' >> ${FILENAME}
        printf "${KUNYOMI}" >> ${FILENAME}
        printf '}' >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    else
        echo "KUNYOMI=${KUNYOMI}"
        printf '%b\\textbf{Kun-Yomi (Unihan):} ' >> ${FILENAME}
        printf '%b\\textsf{' >> ${FILENAME}
        printf "${KUNYOMI}" >> ${FILENAME}
        printf '}' >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    fi
else
    echo "KUNYOMI=${KUNYOMI}"
    printf '%b\\textbf{Kun-Yomi:} ' >> ${FILENAME}
    printf '%b\\textsf{' >> ${FILENAME}
    printf "${KUNYOMI}" >> ${FILENAME}
    printf '}' >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

NANORI="`egrep -A 1 '^/kanjidic2/character/reading_meaning/nanori$' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/reading_meaning/nanori$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/reading_meaning\/nanori=//' | sed 's/$/\;/' | tr -d '\n' | sed 's/\;/\;\ /g' | sed 's/;\ $/\./' | sed 's/\ $//'`"

echo "NANORI=${NANORI}"

if test "$NANORI" = "" -o  "$NANORI" = " "
then
    :
else
    printf '%b\\textbf{Nanori:} ' >> ${FILENAME}
    printf '%b\\textsf{' >> ${FILENAME}
    printf "${NANORI}" >> ${FILENAME}
    printf '}' >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

GRADE="`egrep '^/kanjidic2/character/misc/grade' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/misc/grade$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/misc\/grade=//' | sed 's/$/\./' | tr -d '\n'`"

echo "GRADE=${GRADE}"

if test "$GRADE" = "" -o  "$GRADE" = " "
then
    :
else
    printf '%b\\textbf{Grade:} ' >> ${FILENAME}
    printf "${GRADE}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi


FREQ="`egrep '^/kanjidic2/character/misc/freq' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/misc/freq$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/misc\/freq=//' | sed 's/$/\./' | tr -d '\n' | sed 's/\ $//'`"

echo "FREQ=${FREQ}"

if test "$FREQ" = "" -o  "$FREQ" = " "
then
    :
else
    printf '%b\\textbf{Frequency:} ' >> ${FILENAME}
    printf "${FREQ}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

JLPT="`egrep '^/kanjidic2/character/misc/jlpt' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/misc/jlpt$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/misc\/jlpt=//' | sed 's/$/\./' | tr -d '\n' | sed 's/\ $//'`"

echo "JLPT=${JLPT}"

if test "$JLPT" = "" -o  "$JLPT" = " "
then
    :
else
    printf '%b\\textbf{JLPT:} ' >> ${FILENAME}
    printf "${JLPT}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

STROKECOUNT="`egrep '^/kanjidic2/character/misc/stroke_count' < ${CURRVAL}.xml2 | egrep -v '^/kanjidic2/character/misc/stroke_count$' | grep -v '^--$' | sed 's/\/kanjidic2\/character\/misc\/stroke_count=//' | head -n 1 | sed 's/$/\./' | tr -d '\n' | sed 's/\ $//'`"

if test "$STROKECOUNT" = "" -o  "$STROKECOUNT" = " "
then
    STROKECOUNT="`grep kTotalStrokes ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\ $//'`"
    if test "$STROKECOUNT" = "" -o  "$STROKECOUNT" = " "
    then
        echo "STROKECOUNT=${STROKECOUNT}"
        printf '%b\\textbf{Strokecount:} ' >> ${FILENAME}
        printf "${STROKECOUNT}" >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    else
        echo "STROKECOUNT=${STROKECOUNT}"
        printf '%b\\textbf{Strokecount (Unihan):} ' >> ${FILENAME}
        printf "${STROKECOUNT}" >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    fi
else
    echo "STROKECOUNT=${STROKECOUNT}"
    printf '%b\\textbf{Strokecount:} ' >> ${FILENAME}
    printf "${STROKECOUNT}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi


SKIPCODE="`egrep '^/kanjidic2/character/query_code/q_code' < ${CURRVAL}.xml2 | grep -A 1 '/kanjidic2/character/query_code/q_code/@qc_type=skip' | egrep '/kanjidic2/character/query_code/q_code=[0-9]*-[0-9]*-[0-9]*' | sed 's/\/kanjidic2\/character\/query_code\/q_code=//'  | tr -d '\n' | sed 's/\ $//'`"

echo "SKIPCODE=${SKIPCODE}"

printf '%b\\textbf{SKIP-code:} ' >> ${FILENAME}
printf "${SKIPCODE}" >> ${FILENAME}
printf '%b\\\\* \n' >> ${FILENAME}

FOURCORNER="`egrep '^/kanjidic2/character/query_code/q_code' < ${CURRVAL}.xml2 | grep -A 1 '/kanjidic2/character/query_code/q_code/@qc_type=four_corner' | egrep '/kanjidic2/character/query_code/q_code=[0-9][0-9][0-9][0-9]' | sed 's/\/kanjidic2\/character\/query_code\/q_code=//' | tr '\n' ' ' | sed 's/\ $//'`"
if test "$FOURCORNER" = "" -o  "$FOURCORNER" = " "
then
    FOURCORNER="`grep kFourCornerCode  ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\ $//'`"
    if test "$FOURCORNER" = "" -o  "$FOURCORNER" = " "
    then
        :
    else
        echo "FOURCORNER=${FOURCORNER}"
        
        printf '%b\\textbf{Four Corner -code (Unihan):} ' >> ${FILENAME}
        printf "${FOURCORNER}" >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    fi
else
    echo "FOURCORNER=${FOURCORNER}"
    
    printf '%b\\textbf{Four Corner -code:} ' >> ${FILENAME}
    printf "${FOURCORNER}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

RADICALS_KRAD="`egrep "^${CURRCHAR}\ :\ " kradfile.all | sed 's/^.*\ :\ //' | sed 's/\ $//'`"
if test "$RADICALS_KRAD" = "" -o  "$RADICALS_KRAD" = " "
then
    :
else
    echo "RADICALS_KRAD=${RADICALS_KRAD}"
    
    printf '%b\\textbf{Radicals (kradfile(2)):} ' >> ${FILENAME}
    printf '%b\\textsf{' >> ${FILENAME}
    printf "${RADICALS_KRAD}" >> ${FILENAME}
    printf '}' >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi


RADICALS_KXZ="`egrep '^/kanjidic2/character/radical/rad_value' < ${CURRVAL}.xml2 | grep -A 1 '/kanjidic2/character/radical/rad_value/@rad_type=classical' | egrep '/kanjidic2/character/radical/rad_value=[0-9]' | sed 's/\/kanjidic2\/character\/radical\/rad_value=//' | tr '\n' ' ' | sed 's/\ $//'`"

if test "$RADICALS_KXZ" = "" -o  "$RADICALS_KXZ" = " "
then
    RADICALS_KXZ="`grep kRSKangXi ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\ $//'`"
    if test "$RADICALS_KXZ" = "" -o  "$RADICALS_KXZ" = " "
    then
        :
    else
        echo "RADICALS_KXZ=${RADICALS_KXZ}"
        
        printf '%b\\textbf{Radical (KangXi Zidian) (Unihan):} ' >> ${FILENAME}
        printf "${RADICALS_KXZ}" >> ${FILENAME}
        printf '%b\\\\* \n' >> ${FILENAME}
    fi
else
    echo "RADICALS_KXZ=${RADICALS_KXZ}"
    
    printf '%b\\textbf{Radical (KangXi Zidian):} ' >> ${FILENAME}
    printf "${RADICALS_KXZ}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi


RADICALS_NELSON="`egrep '^/kanjidic2/character/radical/rad_value' < ${CURRVAL}.xml2 | grep -A 1 '/kanjidic2/character/radical/rad_value/@rad_type=nlson_c' | egrep '/kanjidic2/character/radical/rad_value=[0-9]' | sed 's/\/kanjidic2\/character\/radical\/rad_value=//' | tr '\n' ' ' | sed 's/\ $//'`"

if test "$RADICALS_NELSON" = "" -o  "$RADICALS_NELSON" = " "
then
    :
else
    echo "RADICALS_NELSON=${RADICALS_NELSON}"
    
    printf '%b\\textbf{Radical (Classic Nelson):} ' >> ${FILENAME}
    printf "${RADICALS_NELSON}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi

RADICALS_KANWA="`grep kRSKanWa ${CURRVAL}.unihan | cut --fields=3- | tr -d '\n' | sed 's/\ $//'`"
if test "$RADICALS_KANWA" = "" -o  "$RADICALS_KANWA" = " "
then
    :
else
    echo "RADICALS_KANWA=${RADICALS_KANWA}"
    
    printf '%b\\textbf{Radical (Dai Kan-Wa Jiten) (Unihan):} ' >> ${FILENAME}
    printf "${RADICALS_KANWA}" >> ${FILENAME}
    printf '%b\\\\* \n' >> ${FILENAME}
fi


printf '%b\n' >> ${FILENAME}
#echo '\vfill' >> ${FILENAME}
printf '%b\n' >> ${FILENAME}
echo '\end{flushleft}' >> ${FILENAME}
echo '\end{sloppypar}' >> ${FILENAME}
echo '\end{minipage}' >> ${FILENAME}



# More starting LaTeX-file (strip comments)
cat fontsamples_start_kanji_B.tex | egrep -v '^%' >> ${FILENAME}
# All that stuff that depends on environment variables
printf '%b\\title{{\\Large\\textsf{' >> ${FILENAME}
printf ${CURRCHAR} >> ${FILENAME}
printf ' ' >> ${FILENAME}
printf "${CURRUCS}" >> ${FILENAME}
printf '%b}}}\n' >> ${FILENAME}

echo "" >> ${FILENAME}
echo '\date{}' >> ${FILENAME}
echo '\author{}' >> ${FILENAME}
echo '\maketitle' >> ${FILENAME}
echo '\thispagestyle{empty}' >> ${FILENAME}
echo ""  >> ${FILENAME}

echo '\ \\' >> ${FILENAME}
#echo '\vspace{-3cm}' >> ${FILENAME}
echo '\vspace{-3.1cm}' >> ${FILENAME}
echo '\enlargethispage*{3\baselineskip}' >> ${FILENAME}
printf '%b\\myshowallfonts{' >> ${FILENAME}
printf ${CURRCHAR} >> ${FILENAME}
printf '%b}\n' >> ${FILENAME}
echo ""  >> ${FILENAME}
echo "\fussy" >> ${FILENAME}
echo ""  >> ${FILENAME}
echo '\ \\' >> ${FILENAME}

if test ! -f ./mydate.txt
then
    ./mydate.sh
fi

MYDATE="`cat ./mydate.txt`"
echo "\texttt{${MYDATE}"  >> ${FILENAME}

# Ending LaTeX (strip comments)
cat fontsamples_end_kanji.tex | egrep -v '^%' >> ${FILENAME}

# Some important comments to the end of file (we do not want to strip them):
cat fontsamples_bottom.tex >> ${FILENAME}

# And now let’s run XeLaTeX
xelatex -src-specials -file-line-error-style ${FILENAME}
while grep 'Rerun to get' ${CURRVAL}.log > /dev/null
do
    xelatex -src-specials -file-line-error-style ${FILENAME}
done

if grep Overfull ${CURRVAL}.log > /dev/null
then
    touch overfull_list.txt
    echo ${CURRVAL}.pdf >> overfull_list.txt
fi



mv -fv ${CURRVAL}.tex ./tex-tmp/${2}/${2}_${3}_tex/
mv -fv ${CURRVAL}.pdf ./pdf-tmp/${2}/${2}_${3}_pdf/

rm -fv ${CURRVAL}.log
rm -fv ${CURRVAL}.aux
rm -fv ${CURRVAL}.xml2
rm -fv ${CURRVAL}.unihan

# -*- coding: utf-8 -*-

# Local Variables: ***
# mode: Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :
