#!/bin/bash

# Create all font samples

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This script is public domain. There is no warranty.

# Some (l)user-serviceable environment variables are in that file
# called fontsamples.rc.sh

if . ./fontsamples.rc.sh
then
    :
else
    echo "./fontsamples.rc.sh could not be read" 
    exit 1
fi

if . ./checkwwwdirs.sh
then
    :
else
    echo "./checkwwwdirs.sh could not be read" 
    exit 1
fi

if . ./checkworkdirs.sh
then
    :
else
    echo "./checkworkdirs.sh could not be read" 
    exit 1
fi

cd ${WORKDIR} || exit 1

rm -fv doall_files_starttime.txt
date '+%s' > doall_files_starttime.txt

CHARMAP="`locale charmap`"

if test "$CHARMAP" == "UTF-8"
then
    echo "Your environment is UTF-8-safe" >&2
else
    echo "Your environment is not UTF-8-safe" >&2
    exit 1
fi

if test ! -f ./mydate.txt
then
    echo ./mydate.sh
    ./mydate.sh
fi

# XXX: Ensure that every PDF-files has one page:
rm -f pdfpages.txt
touch pdfpages.txt

# Download dictionaries:
# Run it as a background process, while PDFs for kana characters are created

./getdics.sh  > /dev/null 2>&1 &
GETDICSPID="$!"

#############################################################################
# Let’s create some directories

mkdir -p ./pdf 2> /dev/null
mkdir -p ./tex 2> /dev/null
mkdir -p ./index 2> /dev/null
mkdir -p ./du_files 2> /dev/null

rm -f du_files/du_catenate_B.txt
rm -f du_files/du_catenate_human.txt
rm -f du_files/du_catenate_kB.txt
rm -f du_files/du_catenate_MB.txt

touch du_files/du_catenate_B.txt
touch du_files/du_catenate_human.txt
touch du_files/du_catenate_kB.txt
touch du_files/du_catenate_MB.txt

for f in ${WWWDIR} ${WWWDIRTWO}
do
    mkdir -p ${f}/pdf 2> /dev/null
    mkdir -p ${f}/tex 2> /dev/null
    chmod -R u+rwX,go+rX,go-w ${f}/
done


#############################################################################
# Let’s create LaTeX-files and compile them

echo ./doall_subgroup.sh hiragana basic
./doall_subgroup.sh hiragana basic

echo ./doall_subgroup.sh hiragana dakuon
./doall_subgroup.sh hiragana dakuon

echo ./doall_subgroup.sh hiragana handakuon
./doall_subgroup.sh hiragana handakuon

echo ./doall_subgroup.sh hiragana yoo-on
./doall_subgroup.sh hiragana yoo-on

echo ./doall_subgroup.sh hiragana other
./doall_subgroup.sh hiragana other


echo ./doall_subgroup.sh katakana basic
./doall_subgroup.sh katakana basic

echo ./doall_subgroup.sh katakana dakuon
./doall_subgroup.sh katakana dakuon

echo ./doall_subgroup.sh katakana handakuon
./doall_subgroup.sh katakana handakuon

echo ./doall_subgroup.sh katakana yoo-on
./doall_subgroup.sh katakana yoo-on

echo ./doall_subgroup.sh katakana other
./doall_subgroup.sh katakana other


### Not very useful
echo ./doall_subgroup.sh katakana halfwidth
./doall_subgroup.sh katakana halfwidth

### Not very useful
echo ./doall_subgroup.sh katakana circled
./doall_subgroup.sh katakana circled

### Currently very few DFSG-free fonts support Ainu-extensions.
echo ./doall_subgroup.sh katakana ainu
./doall_subgroup.sh katakana ainu

### Now wait until all kanji dictionaries are ready.
wait $GETDICSPID

### Start processing kanjis

echo ./doall_subgroup.sh kanji G1
./doall_subgroup.sh kanji G1

echo ./doall_subgroup.sh kanji G2
./doall_subgroup.sh kanji G2

echo ./doall_subgroup.sh kanji G3
./doall_subgroup.sh kanji G3

echo ./doall_subgroup.sh kanji G4
./doall_subgroup.sh kanji G4

echo ./doall_subgroup.sh kanji G5
./doall_subgroup.sh kanji G5

echo ./doall_subgroup.sh kanji G6
./doall_subgroup.sh kanji G6


echo ./doall_subgroup.sh kanji G8
./doall_subgroup.sh kanji G8

echo ./doall_subgroup.sh kanji G9
./doall_subgroup.sh kanji G9

echo ./doall_subgroup.sh kanji G10
./doall_subgroup.sh kanji G10


echo ./doall_subgroup.sh kanji other-common
./doall_subgroup.sh kanji other-common

echo ./doall_subgroup.sh kanji other-uncommon1
./doall_subgroup.sh kanji other-uncommon1

# Very big!
echo ./doall_subgroup.sh kanji other-uncommon2
./doall_subgroup.sh kanji other-uncommon2

echo ./doall_subgroup.sh kanji other-uncommon3
./doall_subgroup.sh kanji other-uncommon3

# Only for the hardcore-learners of kanji!
echo ./doall_subgroup.sh kanji other-uncommon4
./doall_subgroup.sh kanji other-uncommon4


###############################################################################
# Every LaTeX-file is now created and compiled.
#

cd ${WORKDIR}

rmdir ${WORKDIR}/pdf/hiragana 2> /dev/null
rmdir ${WORKDIR}/pdf/kanji 2> /dev/null
rmdir ${WORKDIR}/pdf/katakana 2> /dev/null
rmdir ${WORKDIR}/tex/hiragana 2> /dev/null
rmdir ${WORKDIR}/tex/kanji 2> /dev/null
rmdir ${WORKDIR}/tex/katakana 2> /dev/null

rmdir ${WORKDIR}/pdf-tmp/hiragana 2> /dev/null
rmdir ${WORKDIR}/pdf-tmp/kanji 2> /dev/null
rmdir ${WORKDIR}/pdf-tmp/katakana 2> /dev/null
rmdir ${WORKDIR}/tex-tmp/hiragana 2> /dev/null
rmdir ${WORKDIR}/tex-tmp/kanji 2> /dev/null
rmdir ${WORKDIR}/tex-tmp/katakana 2> /dev/null

# This should not be released in WWW
rm -f pdfpages2.txt
touch pdfpages2.txt
sort pdfpages.txt | uniq >> pdfpages2.txt
mv -f pdfpages2.txt pdfpages.txt


cd ${WORKDIR}

rm -fv doall_files_endtime.txt
date '+%s' > doall_files_endtime.txt

# -*- coding: utf-8 -*-

# Local Variables: ***
# mode:Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :

