#!/bin/bash


# Get all needed dictionaries.

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This script is public domain. There is no warranty.

# Some (l)user-serviceable environment variables are in that file
# called fontsamples.rc.sh

if . ./fontsamples.rc.sh
then
    :
else
    echo "./fontsamples.rc.sh could not be read" 
    exit 1
fi

if . ./checkworkdirs.sh
then
    :
else
    echo "./checkworkdirs.sh could not be read" 
    exit 1
fi

cd ${WORKDIR} || exit 1

CHARMAP="`locale charmap`"

if test "$CHARMAP" == "UTF-8"
then
    echo "Your environment is UTF-8-safe" >&2
else
    echo "Your environment is not UTF-8-safe" >&2
    exit 1
fi


#############################################################################
# We need kanjidic

if test ! -f ./kanjidic
then
    #curl -L -O http://ftp.monash.edu.au/pub/nihongo/kanjidic.gz || exit 1
    lftp -c 'get ftp://ftp.monash.edu.au/pub/nihongo/kanjidic.gz' || exit 1
    gunzip -v kanjidic.gz
    # recode EUC-JP..UTF-8 < kanjidic > kanjidic.utf8
    iconv -f EUC-JP -t UTF-8 kanjidic -o kanjidic.utf8
    mv -f kanjidic.utf8 kanjidic
fi

if test ! -f ./kanjidic
then
    echo "kanjidic could not be downloaded" >&2
    exit 1
fi


#############################################################################
# We need kanjd212

if test ! -f ./kanjd212
then
    #curl -L -O http://ftp.monash.edu.au/pub/nihongo/kanjd212.gz || exit 1
    lftp -c 'get ftp://ftp.monash.edu.au/pub/nihongo/kanjd212.gz' || exit 1
    gunzip -v kanjd212.gz
    # recode EUC-JP..UTF-8 < kanjd212 > kanjd212.utf8
    iconv -f EUC-JP -t UTF-8 kanjd212 -o kanjd212.utf8
    mv -f kanjd212.utf8 kanjd212
fi

if test ! -f ./kanjd212
then
    echo "kanjd212 could not be downloaded" >&2
    exit 1
fi


#############################################################################
# Put two dictionaries together

if test ! -f ./kanjidic.all
then
    touch kanjidic.all
    cat kanjidic kanjd212 | egrep -v '^#' | sort | uniq >> kanjidic.all
fi

if test ! -f ./kanjidic.all
then
    echo "kanjidic.all could not be created" >&2
    exit 1
fi


#############################################################################
# We need kradfile and kradfile2

if test ! -f ./kradfile.all
then
    #curl -L -O ftp://ftp.monash.edu.au/pub/nihongo/kradzip.zip || exit 1
    lftp -c 'get ftp://ftp.monash.edu.au/pub/nihongo/kradzip.zip' || exit 1
    unzip kradzip.zip
    rm -f kradintro kradzip.zip radkfile radkfile2 radkfilex radkintro radkintro2 radkintrox
    
    # recode EUC-JP..UTF-8 < kradfile > kradfile.utf8
    iconv -f EUC-JP -t UTF-8 kradfile -o kradfile.utf8
    mv -f kradfile.utf8 kradfile
    
    # recode EUC-JP..UTF-8 < kradfile2 > kradfile2.utf8
    iconv -f EUC-JP -t UTF-8 kradfile2 -o kradfile2.utf8
    mv -f kradfile2.utf8 kradfile2
    
    # Put two dictionaries together
    rm -f kradfile.all
    touch kradfile.all
    cat kradfile kradfile2 | egrep -v '^#' | sort | uniq >> kradfile.all
fi

if test ! -f ./kradfile.all
then
    echo "kradfile and kradfile2 could not be downloaded" >&2
    exit 1
fi


#############################################################################
# We need kanjidic2.xml

if test ! -f ./kanjidic2.xml
then
    #curl -L -O http://www.csse.monash.edu.au/~jwb/kanjidic2/kanjidic2.xml.gz || exit 1
    lftp -c 'get http://www.csse.monash.edu.au/~jwb/kanjidic2/kanjidic2.xml.gz' || exit 1
    gunzip -v kanjidic2.xml.gz
fi

if test ! -f ./kanjidic2.xml
then
    echo "kanjidic2.xml could not be downloaded" >&2
    exit 1
fi


#############################################################################
# We need Unihan.txt

if test ! -f ./Unihan.txt
then
    rm -f Unihan.zip 2> /dev/null
    #curl -L -O ftp://ftp.unicode.org/Public/UNIDATA/Unihan.zip || exit 1
    lftp -c 'get ftp://ftp.unicode.org/Public/UNIDATA/Unihan.zip' || exit 1
    unzip Unihan.zip && rm -f ./Unihan.zip
    touch Unihan.txt
    cat Unihan_Readings.txt Unihan_DictionaryLikeData.txt Unihan_RadicalStrokeCounts.txt | egrep -v '^#' | sort | uniq >> Unihan.txt 
    rm -f Unihan_*.txt Unihan.zip
fi

if test ! -f ./Unihan.txt
then
    echo "Unihan.txt could not be downloaded" >&2
    exit 1
fi

if test ! -f ./kanjidic_kanjis_all.txt
then
    touch ./kanjidic_kanjis_all.txt
    for f in `xml2 < kanjidic2.xml | grep '/kanjidic2/character/literal=' | sed 's/\/kanjidic2\/character\/literal\=//'`
    do
        echo "${f} " >> kanjidic_kanjis_all.txt
    done
    echo "" >> kanjidic_kanjis_all.txt
fi

if test ! -f ./unicode_kanjis_all.txt
then
    rm -f ./unicode_kanjis_tmp.txt
    touch ./unicode_kanjis_tmp.txt
    cat Unihan.txt | egrep -v '^#' | grep kJapaneseKun >> ./unicode_kanjis_tmp.txt
    cat Unihan.txt | egrep -v '^#' | grep kJapaneseOn >> ./unicode_kanjis_tmp.txt
    touch ./unicode_kanjis_all.txt
    for f in `cat ./unicode_kanjis_tmp.txt | awk '{print $1}' | sort | uniq`
    do
        unicode --colour=off "${f}" | head -n 3 | tail -n 1 | awk '{print $1}' >> ./unicode_kanjis_all.txt
    done
    rm -f ./unicode_kanjis_tmp.txt
fi

if test ! -f ./unicode_only_kanjis_all.txt
then
    touch ./unicode_only_kanjis_all.txt
    for g in `cat ./unicode_kanjis_all.txt`
    do
        if grep "$g" kanjidic_kanjis_all.txt > /dev/null 2>&1
        then
            :
        else
            echo "$g" >> ./unicode_only_kanjis_all.txt
        fi
    done
fi



