#!/bin/bash

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This file is public domain. There is no warranty.

# Usage:
# release_subgroup.sh GROUP SUBGROUP
# Example usage:
# release_subgroup.sh hiragana basic
# release_subgroup.sh kanji other-uncommon2

# Some (l)user-serviceable environment variables are in that file
# called fontsamples.rc.sh
if . ./fontsamples.rc.sh
then
    :
else
    echo "./fontsamples.rc.sh could not be read" 
    exit 1
fi

cd ${WORKDIR} || exit 1

if . ./checkworkdirs.sh
then
    :
else
    echo "./checkworkdirs.sh could not be read" 
    exit 1
fi

if . ./checkwwwdirs.sh
then
    :
else
    echo "./checkwwwdirs.sh could not be read" 
    exit 1
fi

if . ./rc.${1}_${2}.sh
then
    :
else
    echo "./rc.${1}_${2}.sh could not be read"
    exit 1
fi

export GROUP
export SUBGROUP
export TEXCOMPRMETHOD
export PDFCOMPRMETHOD
export SUBGROUPWWWDIR

for FORMAT in pdf tex
do
    cd  ${WORKDIR}/${FORMAT}/${GROUP} || exit 1
    case $FORMAT in
        tex)
        case $TEXCOMPRMETHOD in
            tarbztwo)
            if test -f ${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2
            then
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.7z
                mkdir -p ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP} 2> /dev/null
                mv  ${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2 ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/
                cd ${WORKDIR} || exit 1
            fi
            ;;
            sevenzip)
            if test -f ${GROUP}_${SUBGROUP}_${FORMAT}.7z
            then
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.7z
                mkdir -p ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP} 2> /dev/null
                mv  ${GROUP}_${SUBGROUP}_${FORMAT}.7z ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/
                cd ${WORKDIR} || exit 1
            fi
            ;;
            *)
            echo 'WTF? What is TEXCOMPRMETHOD called '"$TEXCOMPRMETHOD"' ?' 
        esac
        ;;
        pdf)
        case $PDFCOMPRMETHOD in
            tarbztwo)
            if test -f ${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2
            then
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.7z
                mkdir -p ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP} 2> /dev/null
                mv  ${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2 ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/
                cd ${WORKDIR} || exit 1
            fi
            ;;
            sevenzip)
            if test -f ${GROUP}_${SUBGROUP}_${FORMAT}.7z
            then
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.tar.bz2
                rm -f ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/${GROUP}_${SUBGROUP}_${FORMAT}.7z
                mkdir -p ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP} 2> /dev/null
                mv  ${GROUP}_${SUBGROUP}_${FORMAT}.7z ${SUBGROUPWWWDIR}/${FORMAT}/${GROUP}/
                cd ${WORKDIR} || exit 1
            fi
            ;;
            *)
            echo 'WTF? What is PDFCOMPRMETHOD called '"$PDFCOMPRMETHOD"' ?' 
        esac
        ;;

        *)
        echo 'WTF? What is FORMAT called '"$FORMAT"' ?' 
    esac
done

cd ${WORKDIR}

for f in ${WWWDIR} ${WWWDIRTWO}
do
    mkdir ${f}/juhtolv-fontsamples-index 2> /dev/null
    cp -u ${WORKDIR}/index/* ${f}/juhtolv-fontsamples-index/
    chmod -R ugo-x,ugo+r,go-w ${f}/juhtolv-fontsamples-index/* 

    mkdir ${f}/juhtolv-fontsamples-du_files 2> /dev/null
    cp -u ${WORKDIR}/du_files/* ${f}/juhtolv-fontsamples-du_files/
    chmod -R ugo-x,ugo+r,go-w ${f}/juhtolv-fontsamples-du_files/*

    cd ${f}/ || exit 1
    rm -f juhtolv-fontsamples-index.tar.bz2
    echo "$TAR_BIN -c -f - juhtolv-fontsamples-index | bzip2 -9 > juhtolv-fontsamples-index.tar.bz2"
    $TAR_BIN -c -f - juhtolv-fontsamples-index | bzip2 -9 > juhtolv-fontsamples-index.tar.bz2

    rm -f juhtolv-fontsamples-du_files.tar.bz2
    echo "$TAR_BIN -c -f - juhtolv-fontsamples-du_files | bzip2 -9 > juhtolv-fontsamples-du_files.tar.bz2"
    $TAR_BIN -c -f - juhtolv-fontsamples-du_files | bzip2 -9 > juhtolv-fontsamples-du_files.tar.bz2

    chmod -R u+rwX,go+rX,go-w ${f}
done

cd ${WORKDIR}

# XXX: You can remove these:
uploadweb.sh
uploadweb2.sh



# Local Variables: ***
# mode:Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :

